@@ -1,7 +1,8 @@
-from generator import Document, MDList, Paragraph, InlineText, Table
 import inspect
 import logging
 
+from generator import Document, InlineText, MDList, Paragraph, Table
+
 
 def _introduction(doc: Document):
     doc.add_paragraph(
@@ -66,7 +67,8 @@ def _table(doc: Document):
             ['164', '75', '19'],
             ['181', '87', '40']
         ],
-        [Table.Align.LEFT, Table.Align.CENTER, Table.Align.RIGHT]
+        [Table.Align.LEFT, Table.Align.CENTER, Table.Align.RIGHT],
+        0
     )
 
 
